get_geographical_distribution: Get Geographical Distribution

Description Usage Arguments Value

Description

Gets the geographical distribution data from a archived Williams Course Catalog PDF link.

Usage

1
  get_geographical_distribution(link = "http://web.williams.edu/admin/registrar//catalog/catalog0910.pdf")

Arguments

link

A link to a yearly pdf file on the Williams College Registrar's website.

Value

A list of size two with two dataframes(one domestic, one international) with two columns:state/country and number.


benmorton28/ephmetrics documentation built on May 12, 2019, 2:08 p.m.