Description Usage Arguments Value
Gets the geographical distribution data from a archived Williams Course Catalog PDF link.
1 | get_geographical_distribution(link = "http://web.williams.edu/admin/registrar//catalog/catalog0910.pdf")
|
link |
A link to a yearly pdf file on the Williams College Registrar's website. |
A list of size two with two dataframes(one domestic, one international) with two columns:state/country and number.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.